/* ========================================================================== */
/*                                                                            */
/*   Mini-monitor test program for ATtiny2313                                 */
/*   (c) August 2010 Kees Moerman                                             */
/*   Description:                                                             */
/*   Test program for mini (serial port driven, interrupt based) monitor      */
/*   capable of reading/writing RAM memory locations and I/O ports            */
/*                                                                            */
/* 	Commands:                                                                 */
/*	- a <byte> sets address to <byte> (out: 'a=')                             */
/*	- r reads byte (out: value)                                               */
/*	- w <byte> writes byte to address (out: 'w!')                             */
/*	- i increment address (out: <value>)                                      */
/*	- space: just echoed                                                      */
/*  See MiniMon.exe on Windows for more user-friendly interface               */
/*	Reminder: Memory map 00..1F register file, 20..5F: I/O ports, 60..DF: RAM */
/*                                                                            */
/*	User callable function: void MiniMonInitUART (int baudrate_factor)        */
/*	Code size 0c + (E8 - 66) = 0x8E (142, 7%) bytes; 8 bytes stack, 2 RAM     */
/*                                                                            */
/* ========================================================================== */


// Pins and Functions
// ------------------
// PD0	Pin 2 	= RS232 RX (TTL, inverted) from RFID reader SEROUT, through an inverter
// PD1	Pin 3 	= RS232 TX (TTL, inverted) to serial LCD, through an inverter

#include <avr/io.h>
#include <avr/interrupt.h>
#include "../MiniMon.h"			// also includes actual code :-( 



// ------------------------------- test routines ------------------------- //

unsigned char ReceiveByte (void)
{
  // Wait for incomming data
  while (!(UCSRA & (1 << RXC)));
  // Return the data
  return UDR;
}

void TransmitByte (char data)
{
  // Wait for empty transmit buffer
  while (!(UCSRA & (1 << UDRE)));
  // Start transmittion
  UDR = data;
}

void TransmitString(char *s)
{
	int i;
	for (i=0; s[i] != '\0'; i++)
	{ TransmitByte(s[i]); }
}

// ---------------- Mini monitor test program --------------------------- //

int main (void)
{
	uint8_t i;
	MiniMonInitUART (25);     			// Set to 9600 bps for a 4.0000 MHz crystal
	TransmitString("Mini-monitor 0.1 test...\n\r");

	sei();          					// Enable Interrupts

	while (1)
    {
		for (i = 0; i < 200; i++);
    }
}


// end of file
